# Table of Contents

- [fact-sheet-order-and-colors](<./fact-sheet-order-and-colors.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Fact Sheet Order and Colors](<./Fact-Sheet-Order-and-Colors.md>)
  - [Fact Sheet Order and Colors in the Meta Model v4](<./Fact-Sheet-Order-and-Colors/Fact-Sheet-Order-and-Colors-in-the-Meta-Model-v4.md>)
  - [Reordering Fact Sheets](<./Fact-Sheet-Order-and-Colors/Reordering-Fact-Sheets.md>)
  - [Changing the Fact Sheet Color](<./Fact-Sheet-Order-and-Colors/Changing-the-Fact-Sheet-Color.md>)
  - [Was this page helpful?](<./Fact-Sheet-Order-and-Colors/Was-this-page-helpful.md>)
  - [We'd love your feedback!](<./Fact-Sheet-Order-and-Colors/Wed-love-your-feedback.md>)
